@@ -27,6 +27,30 @@ LAMBDA_FUNCTION_NAME='<name you noted earlier>' pytest ./handler_tests/<handler>
 ```
 RUN_LOCALLY='false' LAMBDA_FUNCTION_NAME='<name from AWS>' pytest ./handler_tests/<handler>/test.py -rA --capture=sys
 ```
+
+## Why can't I move an OU?
+
+Moving OUs isn't supported by Organizations and would cause significant issues with keeping track of OUs in the CDK. Imagine a scenario like below:
+
+* You have an ou, `OUAdmin`, and it has 2 children, `OUChild1 and Account1`, that are also managed by the CDK stack.
+* You change the parent of `OUAdmin` to `OUFoo`. The CDK would need to take the following actions:
+
+  * Create a new `OU` under `OUFoo` with the name `OUAdmin`
+  * Move all of the original `OUAdmin` OU's children to the new `OUAdmin`
+  * Delete the old `OUAdmin`
+  * Update all physical resource IDs
+
+    * It would succeed at moving accounts because physical IDs should not change. Accounting moving between OUs is supported by Organizations
+    * It would fail at moving any child OUs because they would also be recreated. Resulting in a change to physical resource ID. Because the custom resource can only managed the resource it's currently acting on, `OUAdmin`, any children OUs would be "lost" in this process and ugly to try and manage.
+
+The best way to move OUs would be to add additional OUs to your org then move any accounts as needed then proceed to delete the OUs, like so:
+
+* Add new OU resources
+* Deploy the stack
+* Change account parents
+* Deploy the stack
+* Remove old OU resources
+* Deploy the stack
 '''
 import abc
 import builtins
@@ -97,7 +121,6 @@ class AccountProps:
     jsii_struct_bases=[],
     name_mapping={
         "name": "name",
-        "allow_merge_on_move": "allowMergeOnMove",
         "allow_recreate_on_update": "allowRecreateOnUpdate",
         "import_on_duplicate": "importOnDuplicate",
     },
@@ -107,22 +130,18 @@ class OUProps:
         self,
         *,
         name: builtins.str,
-        allow_merge_on_move: typing.Optional[builtins.bool] = None,
         allow_recreate_on_update: typing.Optional[builtins.bool] = None,
         import_on_duplicate: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties of an OU.
 
         :param name: The name of the OU.
-        :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
         :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
         :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
-        if allow_merge_on_move is not None:
-            self._values["allow_merge_on_move"] = allow_merge_on_move
         if allow_recreate_on_update is not None:
             self._values["allow_recreate_on_update"] = allow_recreate_on_update
         if import_on_duplicate is not None:
@@ -135,19 +154,6 @@ class OUProps:
         assert result is not None, "Required property 'name' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def allow_merge_on_move(self) -> typing.Optional[builtins.bool]:
-        '''Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs.
-
-        If this is false and the OU already exists an error will be thrown.
-        If this is true and the OU already exists the accounts in the OU will be moved to the existing OU
-        and the duplicate, now empty, OU will be deleted.
-
-        :default: false
-        '''
-        result = self._values.get("allow_merge_on_move")
-        return typing.cast(typing.Optional[builtins.bool], result)
-
     @builtins.property
     def allow_recreate_on_update(self) -> typing.Optional[builtins.bool]:
         '''Whether or not a missing OU should be recreated during an update.
@@ -185,7 +191,6 @@ class OUProps:
     jsii_struct_bases=[OUProps],
     name_mapping={
         "name": "name",
-        "allow_merge_on_move": "allowMergeOnMove",
         "allow_recreate_on_update": "allowRecreateOnUpdate",
         "import_on_duplicate": "importOnDuplicate",
         "parent": "parent",
@@ -197,7 +202,6 @@ class OUResourceProps(OUProps):
         self,
         *,
         name: builtins.str,
-        allow_merge_on_move: typing.Optional[builtins.bool] = None,
         allow_recreate_on_update: typing.Optional[builtins.bool] = None,
         import_on_duplicate: typing.Optional[builtins.bool] = None,
         parent: typing.Union[builtins.str, "OrganizationOU"],
@@ -206,7 +210,6 @@ class OUResourceProps(OUProps):
         '''The properties of an OrganizationOU custom resource.
 
         :param name: The name of the OU.
-        :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
         :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
         :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
         :param parent: The parent OU id.
@@ -217,8 +220,6 @@ class OUResourceProps(OUProps):
             "parent": parent,
             "provider": provider,
         }
-        if allow_merge_on_move is not None:
-            self._values["allow_merge_on_move"] = allow_merge_on_move
         if allow_recreate_on_update is not None:
             self._values["allow_recreate_on_update"] = allow_recreate_on_update
         if import_on_duplicate is not None:
@@ -231,19 +232,6 @@ class OUResourceProps(OUProps):
         assert result is not None, "Required property 'name' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def allow_merge_on_move(self) -> typing.Optional[builtins.bool]:
-        '''Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs.
-
-        If this is false and the OU already exists an error will be thrown.
-        If this is true and the OU already exists the accounts in the OU will be moved to the existing OU
-        and the duplicate, now empty, OU will be deleted.
-
-        :default: false
-        '''
-        result = self._values.get("allow_merge_on_move")
-        return typing.cast(typing.Optional[builtins.bool], result)
-
     @builtins.property
     def allow_recreate_on_update(self) -> typing.Optional[builtins.bool]:
         '''Whether or not a missing OU should be recreated during an update.
@@ -409,7 +397,6 @@ class OrganizationOU(
         parent: typing.Union[builtins.str, "OrganizationOU"],
         provider: aws_cdk.custom_resources.Provider,
         name: builtins.str,
-        allow_merge_on_move: typing.Optional[builtins.bool] = None,
         allow_recreate_on_update: typing.Optional[builtins.bool] = None,
         import_on_duplicate: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -419,7 +406,6 @@ class OrganizationOU(
         :param parent: The parent OU id.
         :param provider: The provider to use for the custom resource that will create the OU. You can create a provider with the OrganizationOuProvider class
         :param name: The name of the OU.
-        :param allow_merge_on_move: Whether or not to merge an OU with a duplicate when an OU is moved between parent OUs. If this is false and the OU already exists an error will be thrown. If this is true and the OU already exists the accounts in the OU will be moved to the existing OU and the duplicate, now empty, OU will be deleted. Default: false
         :param allow_recreate_on_update: Whether or not a missing OU should be recreated during an update. If this is false and the OU does not exist an error will be thrown when you try to update it.
         :param import_on_duplicate: Whether or not to import an existing OU if the new OU is a duplicate. If this is false and the OU already exists an error will be thrown. Default: false
         '''
@@ -427,7 +413,6 @@ class OrganizationOU(
             parent=parent,
             provider=provider,
             name=name,
-            allow_merge_on_move=allow_merge_on_move,
             allow_recreate_on_update=allow_recreate_on_update,
             import_on_duplicate=import_on_duplicate,
         )
